@@ -1,17 +1,17 @@
 """
-Backend implemenation using simplejson
+Backend implemenation using the ``simplejson`` package.
 """
 import contextlib
-import os
-import os.path
 import logging
 import math
+import os
+import os.path
 import re
 
 import simplejson as json
 
+from ..errors import DuplicateError, SearchError
 from .core import _Backend
-from ..errors import SearchError, DuplicateError
 
 logger = logging.getLogger(__name__)
 
@@ -25,10 +25,7 @@ except ImportError:
 
 @contextlib.contextmanager
 def _load_and_store_context(backend):
-    '''
-    A context manager to load, and optionally store the JSON database at the
-    end
-    '''
+    """Context manager used to load, and optionally store the JSON database."""
     db = backend._load_or_initialize()
     yield db
     backend.store(db)
@@ -36,29 +33,27 @@ def _load_and_store_context(backend):
 
 class JSONBackend(_Backend):
     """
-    JSON database
+    JSON database.
 
-    The happi information is kept in a single dictionary large dictionary that
-    is stored using `simplejson`
+    The happi information is kept in a single large dictionary that is stored
+    using the ``simplejson`` package.
 
     Parameters
     ----------
     path : str
-        Path to JSON file
-
+        Path to JSON file.
     initialze : bool, optional
-        Initialize a new empty JSON file to begin filling
+        Initialize a new empty JSON file to begin filling.
     """
+
     def __init__(self, path, initialize=False):
-        self.path = path
+        self.path = os.path.expanduser(path)
         # Create a new JSON file if requested
         if initialize:
             self.initialize()
 
     def _load_or_initialize(self):
-        '''
-        Load an existing database or initialize a new one.
-        '''
+        """Load an existing database or initialize a new one."""
         try:
             return self.load()
         except FileNotFoundError:
@@ -69,27 +64,26 @@ class JSONBackend(_Backend):
 
     @property
     def all_devices(self):
-        """
-        All of the devices in the database
-        """
+        """All of the devices in the database."""
         json = self._load_or_initialize()
         return list(json.values())
 
     def initialize(self):
         """
-        Initialize a new JSON file database
+        Initialize a new JSON file database.
 
         Raises
         ------
-        PermissionError:
-            If the JSON file specified by `path` already exists
+        PermissionError
+            If the JSON file specified by ``path`` already exists.
 
         Notes
         -----
-        This is exists because the `store` and `load` methods assume that the
+        This exists because the `.store` and `.load` methods assume that the
         given path already points to a readable JSON file. In order to begin
-        filling a new database, an empty but valid JSON file is created
+        filling a new database, an empty but valid JSON file is created.
         """
+
         # Do not overwrite existing databases
         if os.path.exists(self.path) and os.stat(self.path).st_size > 0:
             raise PermissionError("File {} already exists. Can not initialize "
@@ -98,9 +92,7 @@ class JSONBackend(_Backend):
         self.store({})
 
     def load(self):
-        """
-        Load the JSON database
-        """
+        """Load the JSON database."""
         with open(self.path, 'r') as f:
             raw_json = f.read()
 
@@ -109,18 +101,19 @@ class JSONBackend(_Backend):
 
     def store(self, db):
         """
-        Stache the database back into JSON
+        Stash the database in the JSON file.
 
         Parameters
         ----------
         db : dict
-            Dictionary to store in JSON
+            Dictionary to store in JSON.
 
         Raises
         ------
-        BlockingIOError:
-            If the file is already being used by another happi operation
+        BlockingIOError
+            If the file is already being used by another happi operation.
         """
+
         with open(self.path, 'w+') as f:
             # Create lock in filesystem
             if fcntl is not None:
@@ -136,13 +129,14 @@ class JSONBackend(_Backend):
 
     def _iterative_compare(self, comparison):
         """
-        Yields documents in which ``comparison(name, doc)`` returns True.
+        Yields documents in which ``comparison(name, doc)`` returns `True`.
 
         Parameters
         ----------
         comparison : callable
-            A comparison function with a signature of (device_id, doc)
+            A comparison function with a signature of (device_id, doc).
         """
+
         db = self._load_or_initialize()
         if not db:
             return
@@ -155,25 +149,20 @@ class JSONBackend(_Backend):
                 logger.debug('Comparison method failed: %s', ex, exc_info=ex)
 
     def get_by_id(self, id_):
-        '''
-        Get a device by ID if it exists, or None
-
-        Parameters
-        ----------
-        id_
-        '''
+        """Get a device by ID if it exists, or return None."""
         db = self._load_or_initialize()
         return db.get(id_)
 
     def find(self, to_match):
         """
-        Find an instance or instances that matches the search criteria
+        Find an instance or instances that matches the search criteria.
 
         Parameters
         ----------
         to_match : dict
-            Requested information, all of which must match
+            Requested information, all of which must match.
         """
+
         def comparison(name, doc):
             return all(value == doc[key]
                        for key, value in to_match.items())
@@ -188,17 +177,15 @@ class JSONBackend(_Backend):
         Parameters
         ----------
         key : str
-            The database key to search
-
+            The database key to search.
         start : int or float
-            Inclusive minimum value to filter ``key`` on
-
+            Inclusive minimum value to filter ``key`` on.
         end : float, optional
-            Exclusive maximum value to filter ``key`` on
-
+            Exclusive maximum value to filter ``key`` on.
         to_match : dict
-            Requested information, where the values must match exactly
+            Requested information, where the values must match exactly.
         """
+
         def comparison(name, doc):
             if all(value == doc[k] for k, value in to_match.items()):
                 value = doc.get(key)
@@ -227,6 +214,7 @@ class JSONBackend(_Backend):
         to_match : dict
             Requested information, where the values are regular expressions.
         """
+
         def comparison(name, doc):
             return regexes and all(key in doc and regex.match(str(doc[key]))
                                    for key, regex in regexes.items())
@@ -240,31 +228,29 @@ class JSONBackend(_Backend):
 
     def save(self, _id, post, insert=True):
         """
-        Save information to the database
+        Save information to the database.
 
         Parameters
         ----------
         _id : str
-            ID of device
-
+            ID of device.
         post : dict
-            Information to place in database
-
+            Information to place in database.
         insert : bool, optional
-            Whether or not this a new device to the database
+            Whether or not this is a new device to the database.
 
         Raises
         ------
-        DuplicateError:
-            If insert is True, but there is already a device with the provided
-            _id
-
-        SearchError:
-            If insert is False, but there is no device with the provided _id
-
-        PermissionError:
-            If the write operation fails due to issues with permissions
+        DuplicateError
+            If ``insert`` is `True`, but there is already a device with the
+            provided ``_id``.
+        SearchError
+            If ``insert`` is `False`, but there is no device with the provided
+            ``_id``.
+        PermissionError
+            If the write operation fails due to issues with permissions.
         """
+
         with _load_and_store_context(self) as db:
             # New device
             if insert:
@@ -284,18 +270,19 @@ class JSONBackend(_Backend):
 
     def delete(self, _id):
         """
-        Delete a device instance from the database
+        Delete a device instance from the database.
 
         Parameters
         ----------
         _id : str
-            ID of device
+            ID of device.
 
         Raises
         ------
-        PermissionError:
-            If the write operation fails due to issues with permissions
+        PermissionError
+            If the write operation fails due to issues with permissions.
         """
+
         with _load_and_store_context(self) as db:
             try:
                 db.pop(_id)
