@@ -677,7 +677,11 @@ class Client(collections.abc.Mapping):
         else:
             backend = DEFAULT_BACKEND
 
-        logger.debug("Using Happi backend %r with kwargs", backend, db_kwargs)
+        logger.debug(
+            "Using Happi backend %r with kwargs %s",
+            backend, db_kwargs
+        )
+
         # Create our database with provided kwargs
         try:
             database = backend(**db_kwargs)
